==> ev_framework-3.0.2.tar.gz: lib/_FrameWork/Ev/_Form_Date.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../vForm.dart';
import '../vText.dart';
import '../vSystem.dart';

class $$Form_Date extends StatefulWidget {
  vForm form;
  var skey;
  var value;

  TextEditingController controller;
  var label_text;
  var start_date;
  var end_date;
  var color;

  $$Form_Date(Key key,this.skey,this.form,this.value,this.controller,
      {this.label_text,this.start_date,this.end_date,this.color}):super(key:key);

  @override
  _Form_Date_State createState() => _Form_Date_State();
}

class _Form_Date_State extends State<$$Form_Date> {
  var value;
  var password_on;
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    value = widget.value;
    form = widget.form;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Widget child = TextField(
      textAlign: form.$$_Text_Align,
      minLines: 1,
      style: TextStyle(
          fontSize: form.$$_Input_Size, color: form.$$_Input_Color),

      decoration: new InputDecoration(
        border: InputBorder.none,
        hintText: "YYYY-MM-DD",
        hintStyle: TextStyle(fontSize: 13, color: Colors.grey.withOpacity(0.7)),
        contentPadding: EdgeInsets.all(8),
        counterText: "",
        isDense: true,

      ),
      controller: widget.controller,
      maxLength: 20,
      keyboardType: TextInputType.datetime,
    );

    child = Row(children: [
        Expanded(child: child),
        SizedBox(width: 5,),
        Material(
          child : InkWell(
            child : Icon(
              Icons.date_range,
              color: form.$$_Lable_Color.withOpacity(0.8),
              size: 26,
            ),
            onTap : () {  Show_Date(context);
            },
          ),
        ),

        SizedBox(width: 5,),
      ],);

    /*
    Widget child = Container(padding:EdgeInsets.all(4),
        width: double.infinity,
        child:Text(value,style:TextStyle(
        fontSize: form.$$_Input_Size, color: form.$$_Input_Color),));
*/


    if (form.$$_Border_type == 1) {
       return form_type1(child);
    }
    else {
      return form_type2(child);
    }
  }

  Widget form_type1(Widget child) {
    var color = form.$$_item_error[widget.skey] == null
        ? form.$$_Border_Color
        : Colors.red;
    var error_text = form.$$_item_error[widget.skey] ?? "";


    return Container(
      padding: form.$$_Padding,
      child: Column(
        crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
        children: <Widget>[
          (form.$$_Lable_ratio > 0) ?
          Row(
              children: <Widget>[
                Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                SizedBox(width: 10),
                Expanded(flex: 100,child: child)
              ]):

          Row(
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.only(bottom:8.0),
                  child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                ),
                SizedBox(width: 10),
                Expanded(child: child)
              ]),

          Container(color: color, height: 1,),
          Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),
            textAlign: TextAlign.right,),
        ],
      ),
    );
  }


  Widget form_type2(Widget child) {
    var error_text = form.$$_item_error[widget.skey] ?? "";


    var decoration = BoxDecoration(
      border: Border.all(
        color: form.$$_item_error[widget.skey] == null
            ? form.$$_Border_Color
            : Colors.red,
        width: form.$$_Border_Width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(form.$$_Round)),
    );

    return Container(
      padding: form.$$_Margin,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child: Row(children: [
                    Padding(
                      padding: const EdgeInsets.only(bottom:8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                    ),
                    SizedBox(width: 10),
                    ],),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                    Column(
                   crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                   children: [
                    Container(padding: form.$$_Padding, child: child,
                      decoration: decoration,

                    ),
                    Padding(
                      padding: EdgeInsets.symmetric(horizontal: form.$$_Round + 5),
                      child: Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),),
                    ),
                  ],
                 ),

                )
              ]),


        ],
      ),
    );
  }

  Future Show_Date(BuildContext context)
  async {

    var first_date = (widget.start_date == null) ? DateTime.now() : DateTime.parse(widget.start_date);
    var initdate = widget.value == "" ?  DateTime.now() : DateTime.parse(widget.value);
    var last_date = widget.end_date == null ? DateTime(DateTime.now().year + 10) : DateTime.parse(widget.end_date);

    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: initdate,
        firstDate: first_date,
        lastDate: last_date,
        builder: (BuildContext context, Widget child) {
        return Theme(
          data: ThemeData.light().copyWith(
            colorScheme: ColorScheme.dark(
              primary: widget.color,
              onPrimary: Colors.white,
              surface: widget.color,
              onSurface: Colors.black,
            ),
          ),
          child: child,
        );
      },
    );

    if (picked != null)
    { var month = int.parse(picked.month.toString());
    var day = int.parse(picked.day.toString());
    var month_txt = month > 9 ? "$month" : "0$month";
    var day_txt = day > 9 ? "$day" : "0$day";

    var date = "${picked.year}-$month_txt-$day_txt";
       setState(() {
         widget.controller.text = date;
         value = date;

       });
    }
  }
}

==> ev_framework-3.0.10.tar.gz: lib/_FrameWork/Ev/_Form_Date.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

import '../vForm.dart';
import '../vText.dart';
import '../vSystem.dart';

class $$Form_Date extends StatefulWidget {
  vForm form;
  var skey;
  var value;

  TextEditingController controller;
  var label_text;
  var start_date;
  var end_date;
  var color;

  $$Form_Date(Key key,this.skey,this.form,this.value,this.controller,
      {this.label_text,this.start_date,this.end_date,this.color}):super(key:key);

  @override
  _Form_Date_State createState() => _Form_Date_State();
}

class _Form_Date_State extends State<$$Form_Date> {
  var value;
  var password_on;
  vForm form;

  @override
  void initState() {
    // TODO: implement initState
    value = widget.value;
    form = widget.form;
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    Widget child = TextField(
      textAlign: form.$$_Text_Align,
      minLines: 1,
      style: TextStyle(
          fontSize: form.$$_Input_Size, color: form.$$_Input_Color),

      decoration: new InputDecoration(
        border: InputBorder.none,
        hintText: "YYYY-MM-DD",
        hintStyle: TextStyle(fontSize: 13, color: Colors.grey.withOpacity(0.7)),
        contentPadding: EdgeInsets.all(8),
        counterText: "",
        isDense: true,

      ),
      controller: widget.controller,
      maxLength: 20,
      keyboardType: TextInputType.datetime,
    );

    child = Row(children: [
        Expanded(child: child),
        SizedBox(width: 5,),
        Material(
          child : InkWell(
            child : Icon(
              Icons.date_range,
              color: form.$$_Lable_Color.withOpacity(0.8),
              size: 26,
            ),
            onTap : () {  Show_Date(context);
            },
          ),
        ),

        SizedBox(width: 5,),
      ],);

    /*
    Widget child = Container(padding:EdgeInsets.all(4),
        width: double.infinity,
        child:Text(value,style:TextStyle(
        fontSize: form.$$_Input_Size, color: form.$$_Input_Color),));
*/


    if (form.$$_Border_type == 1) {
       return form_type1(child);
    }
    else {
      return form_type2(child);
    }
  }

  Widget form_type1(Widget child) {
    var color = form.$$_item_error[widget.skey] == null
        ? form.$$_Border_Color
        : Colors.red;
    var error_text = form.$$_item_error[widget.skey] ?? "";


    return Container(
      padding: form.$$_Margin,
      child: Column(
        crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
        children: <Widget>[
          Padding(padding: form.$$_Padding,child: (form.$$_Lable_ratio > 0) ?
          Row(
              children: <Widget>[
                Expanded(flex: (form.$$_Lable_ratio * 100).round(), child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size)),
                SizedBox(width: 10),
                Expanded(flex: 100,child: child)
              ]):

          Row(
              children: <Widget>[
                Padding(
                  padding: const EdgeInsets.only(bottom:8.0),
                  child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                ),
                SizedBox(width: 10),
                Expanded(child: child)
              ]),
          ),
          Container(color: color, height: 1,),
          Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),
            textAlign: TextAlign.right,),
        ],
      ),
    );
  }


  Widget form_type2(Widget child) {
    var error_text = form.$$_item_error[widget.skey] ?? "";


    var decoration = BoxDecoration(
      border: Border.all(
        color: form.$$_item_error[widget.skey] == null
            ? form.$$_Border_Color
            : Colors.red,
        width: form.$$_Border_Width,
      ),
      borderRadius: BorderRadius.all(Radius.circular(form.$$_Round)),
    );

    return Container(
      padding: form.$$_Margin,
      child: Column(
        children: <Widget>[
          Row(
              crossAxisAlignment: CrossAxisAlignment.center,
              children: <Widget>[
                widget.label_text == "" ? Container() :

                Expanded(
                  flex: (form.$$_Lable_ratio >0) ? (form.$$_Lable_ratio * 100).round() : 0,
                  child: Row(children: [
                    Padding(
                      padding: const EdgeInsets.only(bottom:8.0),
                      child: vText(widget.label_text).c(form.$$_Lable_Color).size(form.$$_Lable_Size),
                    ),
                    SizedBox(width: 10),
                    ],),
                ),

                Expanded( flex: (form.$$_Lable_ratio >0) ? 100 : 1,
                  child:
                    Column(
                   crossAxisAlignment: form.$$_Text_Align == TextAlign.right ? CrossAxisAlignment.end : CrossAxisAlignment.start,
                   children: [
                    Container(padding: form.$$_Padding, child: child,
                      decoration: decoration,

                    ),
                    Padding(
                      padding: EdgeInsets.symmetric(horizontal: form.$$_Round + 5),
                      child: Text(error_text, style: TextStyle(color: Colors.red, fontSize: 12),),
                    ),
                  ],
                 ),

                )
              ]),


        ],
      ),
    );
  }

  Future Show_Date(BuildContext context)
  async {

    var first_date = (widget.start_date == null) ? DateTime.now() : DateTime.parse(widget.start_date);
    var initdate = widget.value == "" ?  DateTime.now() : DateTime.parse(widget.value);
    var last_date = widget.end_date == null ? DateTime(DateTime.now().year + 10) : DateTime.parse(widget.end_date);

    final DateTime picked = await showDatePicker(
        context: context,
        initialDate: initdate,
        firstDate: first_date,
        lastDate: last_date,
        builder: (BuildContext context, Widget child) {
        return Theme(
          data: ThemeData.light().copyWith(
            colorScheme: ColorScheme.dark(
              primary: widget.color,
              onPrimary: Colors.white,
              surface: widget.color,
              onSurface: Colors.black,
            ),
          ),
          child: child,
        );
      },
    );

    if (picked != null)
    { var month = int.parse(picked.month.toString());
    var day = int.parse(picked.day.toString());
    var month_txt = month > 9 ? "$month" : "0$month";
    var day_txt = day > 9 ? "$day" : "0$day";

    var date = "${picked.year}-$month_txt-$day_txt";
       setState(() {
         widget.controller.text = date;
         value = date;

       });
    }
  }
}
